summaryrefslogtreecommitdiffstats
path: root/packaging
diff options
context:
space:
mode:
authorDaniel Schürmann <daschuer@mixxx.org>2021-09-11 18:10:58 +0200
committerDaniel Schürmann <daschuer@mixxx.org>2021-09-12 01:36:46 +0200
commitb9f31aa7b3d408c7e4bc3f1c758a889a74d164ab (patch)
tree75bddd5d7bb1e3d3c3cbb05fdb2629eba8e6f0dd /packaging
parent4989a4be3bf653d909e0d8f8575bd5cc98aa2192 (diff)
bump PPA version to 2.4.0~alpha2
This is required because we have added --first-parent to our git describe call which has lowerd the count since last tag to 697 from 6372
Diffstat (limited to 'packaging')
-rw-r--r--packaging/CPackDebUploadPPA.cmake8
1 files changed, 5 insertions, 3 deletions
diff --git a/packaging/CPackDebUploadPPA.cmake b/packaging/CPackDebUploadPPA.cmake
index 23eb1e53ed..de5a21f853 100644
--- a/packaging/CPackDebUploadPPA.cmake
+++ b/packaging/CPackDebUploadPPA.cmake
@@ -43,10 +43,12 @@ if(NOT CPACK_DEBIAN_GPG_RET EQUAL "0")
endif()
# hack to advance the version from the legacy version like this:
# dpkg --compare-versions 2.4.0~alpha~pre1~git7859 lt 2.4.0~alpha1~5463~gf2da9e619d && echo true
# dpkg --compare-versions 2.4.0~alpha1~5463~gf2da9e619d lt 2.4.0 && echo true
if(DEB_UPLOAD_PPA MATCHES "nightlies")
- string(REPLACE "2.4~alpha~" "2.4.0~alpha1~" CPACK_DEBIAN_PACKAGE_VERSION "${CPACK_DEBIAN_PACKAGE_VERSION}")
+ string(REPLACE "2.4~alpha~" "2.4.0~alpha2~" CPACK_DEBIAN_PACKAGE_VERSION "${CPACK_DEBIAN_PACKAGE_VERSION}")
endif()
message(NOTICE "Creating mixxx_${CPACK_DEBIAN_PACKAGE_VERSION}.orig.tar.gz")
@@ -43,10 +43,12 @@ if(NOT CPACK_DEBIAN_GPG_RET EQUAL "0")
endif()
# hack to advance the version from the legacy version like this:
-# dpkg --compare-versions 2.4.0~alpha~pre1~git7859 lt 2.4.0~alpha1~5463~gf2da9e619d && echo true
-# dpkg --compare-versions 2.4.0~alpha1~5463~gf2da9e619d lt 2.4.0 && echo true
+# dpkg --compare-versions 2.4.0~alpha~pre1~git7859 lt 2.4.0~alpha2~5463~gf2da9e619d && echo true
+# and from changing to --first-parent
+# dpkg --compare-versions 2.4.0~alpha1~6372~g0244af2e04-1~impish lt 2.4.0~alpha2~805~g4f13bc1d5d-1~impish && echo true
+# dpkg --compare-versions 2.4.0~alpha2~5463~gf2da9e619d lt 2.4.0 && echo true
if(DEB_UPLOAD_PPA MATCHES "nightlies")